.. expect: missing backtick before hyperlink reference: 'Misc/NEWS <https://github.com/python/cpython/blob/v3.2.6/Misc/NEWS>`_'. (hyperlink-reference-missing-backtick)

In the following line, the hyperlink reference misses its opening backtick
Misc/NEWS <https://github.com/python/cpython/blob/v3.2.6/Misc/NEWS>`_
that's bad.
